## 📝 Summary

<!--
Provide a concise summary of what this pull request is addressing.

If this PR fixes any issues, list them here by number (e.g., Fixes #123).
-->

## 🔍 Description of Changes

<!--
Detail the specific changes made in this pull request. Explain the problem addressed and how it was resolved. If applicable, provide before and after comparisons, screenshots, or any relevant details to help reviewers understand the changes easily.
-->

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] New command
- [ ] New theme
- [ ] Breaking change
- [ ] Documentation update

## Checklist

- [ ] I have tested these changes
- [ ] I have updated documentation
- [ ] My code follows project guidelines

## 📜 Reviewers

<!--
Tag potential reviewers from the community or maintainers who might be interested in reviewing this pull request.

Your PR will be reviewed more quickly if you can figure out the right person to tag with @ -->

@metaboulie
